Merge "Ignore EGL_SWAP_BEHAVIOR_PRESERVED_BIT on low API version"
diff --git a/system/egl/egl.cpp b/system/egl/egl.cpp
index a9024ad..81b0b52 100644
--- a/system/egl/egl.cpp
+++ b/system/egl/egl.cpp
@@ -757,11 +757,11 @@
         attribs_size++; //for the terminating EGL_NONE
     }
 
     // API 16 passes EGL_SWAP_BEHAVIOR_PRESERVED_BIT to surface type,
     // while the host never supports it.
     // We remove the bit here.
     EGLint* local_attrib_list = NULL;
-    if (PLATFORM_SDK_VERSION <= 16) {
+    if (PLATFORM_SDK_VERSION <= 19) {
         local_attrib_list = new EGLint[attribs_size];
         memcpy(local_attrib_list, attrib_list, attribs_size * sizeof(EGLint));
         EGLint* local_attrib_p = local_attrib_list;
@@ -757,11 +757,11 @@
     }
 
-    // API 16 passes EGL_SWAP_BEHAVIOR_PRESERVED_BIT to surface type,
+    // API 19 passes EGL_SWAP_BEHAVIOR_PRESERVED_BIT to surface type,
     // while the host never supports it.
     // We remove the bit here.